@@ -20,9 +20,7 @@
 #ifndef FREERDP_CHANNEL_VIDEO_CLIENT_MAIN_H
 #define FREERDP_CHANNEL_VIDEO_CLIENT_MAIN_H
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <freerdp/config.h>
 
 #include <freerdp/dvc.h>
 #include <freerdp/types.h>
@@ -30,6 +28,4 @@
 
 #include <freerdp/channels/video.h>
 
-
 #endif /* FREERDP_CHANNEL_GEOMETRY_CLIENT_MAIN_H */
-
