@@ -121,21 +121,17 @@ static BOOL gcc_write_server_multitransport_channel_data(wStream* s, const rdpMc
 static rdpSettings* mcs_get_settings(rdpMcs* mcs)
 {
 	WINPR_ASSERT(mcs);
+	WINPR_ASSERT(mcs->context);
 
-	rdpContext* context = transport_get_context(mcs->transport);
-	WINPR_ASSERT(context);
-
-	return context->settings;
+	return mcs->context->settings;
 }
 
 static const rdpSettings* mcs_get_const_settings(const rdpMcs* mcs)
 {
 	WINPR_ASSERT(mcs);
+	WINPR_ASSERT(mcs->context);
 
-	const rdpContext* context = transport_get_context(mcs->transport);
-	WINPR_ASSERT(context);
-
-	return context->settings;
+	return mcs->context->settings;
 }
 
 static char* rdp_early_server_caps_string(UINT32 flags, char* buffer, size_t size)
@@ -343,8 +339,8 @@ static DWORD rdp_version_common(wLog* log, DWORD serverVersion, DWORD clientVers
  */
 static const BYTE t124_02_98_oid[6] = { 0, 0, 20, 124, 0, 1 };
 
-static const BYTE h221_cs_key[4] = "Duca";
-static const BYTE h221_sc_key[4] = "McDn";
+static const BYTE h221_cs_key[4] = { 'D', 'u', 'c', 'a' };
+static const BYTE h221_sc_key[4] = { 'M', 'c', 'D', 'n' };
 
 /**
  * Read a GCC Conference Create Request.
@@ -1786,12 +1782,13 @@ BOOL gcc_read_server_security_data(wStream* s, rdpMcs* mcs)
 
 	Stream_Read(s, settings->ServerCertificate, settings->ServerCertificateLength);
 
-	const BYTE* data = settings->ServerCertificate;
-	const uint32_t length = settings->ServerCertificateLength;
-
-	if (!freerdp_certificate_read_server_cert(settings->RdpServerCertificate, data, length))
-		goto fail;
+	{
+		const BYTE* data = settings->ServerCertificate;
+		const uint32_t length = settings->ServerCertificateLength;
 
+		if (!freerdp_certificate_read_server_cert(settings->RdpServerCertificate, data, length))
+			goto fail;
+	}
 	return TRUE;
 fail:
 	(void)freerdp_settings_set_pointer_len(settings, FreeRDP_ServerRandom, NULL, 0);
@@ -2178,8 +2175,8 @@ BOOL gcc_read_client_monitor_data(wStream* s, rdpMcs* mcs)
 			return FALSE;
 		}
 
-		const INT64 w = right - left;
-		const INT64 h = bottom - top;
+		const INT64 w = 1ll * right - left;
+		const INT64 h = 1ll * bottom - top;
 		if ((w >= INT32_MAX) || (h >= INT32_MAX) || (w < 0) || (h < 0))
 		{
 			WLog_Print(mcs->log, WLOG_ERROR,
