@@ -5,11 +5,14 @@
 
 int TestBufferPool(int argc, char* argv[])
 {
-	DWORD PoolSize;
-	int BufferSize;
-	wBufferPool* pool;
-	BYTE* Buffers[10];
-	DWORD DefaultSize = 1234;
+	DWORD PoolSize = 0;
+	SSIZE_T BufferSize = 0;
+	wBufferPool* pool = NULL;
+	BYTE* Buffers[10] = { 0 };
+	int DefaultSize = 1234;
+
+	WINPR_UNUSED(argc);
+	WINPR_UNUSED(argv);
 
 	pool = BufferPool_New(TRUE, -1, 16);
 	if (!pool)
@@ -25,7 +28,8 @@ int TestBufferPool(int argc, char* argv[])
 
 	if (BufferSize != DefaultSize)
 	{
-		printf("BufferPool_GetBufferSize failure: Actual: %d Expected: %"PRIu32"\n", BufferSize, DefaultSize);
+		printf("BufferPool_GetBufferSize failure: Actual: %" PRIdz " Expected: %" PRIu32 "\n",
+		       BufferSize, DefaultSize);
 		return -1;
 	}
 
@@ -33,7 +37,8 @@ int TestBufferPool(int argc, char* argv[])
 
 	if (BufferSize != DefaultSize)
 	{
-		printf("BufferPool_GetBufferSize failure: Actual: %d Expected: %"PRIu32"\n", BufferSize, DefaultSize);
+		printf("BufferPool_GetBufferSize failure: Actual: %" PRIdz " Expected: %" PRIu32 "\n",
+		       BufferSize, DefaultSize);
 		return -1;
 	}
 
@@ -41,7 +46,7 @@ int TestBufferPool(int argc, char* argv[])
 
 	if (BufferSize != 2048)
 	{
-		printf("BufferPool_GetBufferSize failure: Actual: %d Expected: 2048\n", BufferSize);
+		printf("BufferPool_GetBufferSize failure: Actual: %" PRIdz " Expected: 2048\n", BufferSize);
 		return -1;
 	}
 
@@ -51,7 +56,7 @@ int TestBufferPool(int argc, char* argv[])
 
 	if (PoolSize != 2)
 	{
-		printf("BufferPool_GetPoolSize failure: Actual: %"PRIu32" Expected: 2\n", PoolSize);
+		printf("BufferPool_GetPoolSize failure: Actual: %" PRIu32 " Expected: 2\n", PoolSize);
 		return -1;
 	}
 
@@ -61,4 +66,3 @@ int TestBufferPool(int argc, char* argv[])
 
 	return 0;
 }
-
